<?php

namespace Drupal\photoswipe\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * {@inheritdoc}
 */
class PhotoswipeAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'photoswipe_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('photoswipe.settings');
    if ($view_displays = \Drupal::entityTypeManager()->getStorage('entity_view_display')->loadMultiple(NULL)) {
      // Loop through all entity view displays:
      foreach ($view_displays as $view_display) {
        $components = $view_display->getComponents();
        foreach ($components as $componentName => $component) {
          if (!in_array($component['type'], [
            'photoswipe_field_formatter',
            'photoswipe_responsive_field_formatter',
          ])) {
            // None of our formatters are used, skip this component:
            continue;
          }
          if (!empty($component['third_party_settings']['fences'])) {
            // Explicitely set fences_field_items_wrapper_tag to 'none' if not existing yet.
            if (!isset($component['third_party_settings']['fences']['fences_field_items_wrapper_tag'])) {
              $component['third_party_settings']['fences']['fences_field_items_wrapper_tag'] = TagManagerInterface::NO_MARKUP_VALUE;
            }
            // Explicitely set fences_field_items_wrapper_classes to 'none' if not existing yet.
            if (!isset($component['third_party_settings']['fences']['fences_field_items_wrapper_classes'])) {
              $component['third_party_settings']['fences']['fences_field_items_wrapper_classes'] = TagManagerInterface::NO_MARKUP_VALUE;
            }
            // Save changes:
            $view_display->setComponent($componentName, $component)->save();
          }
        }
      }
    }

    $form['enable_cdn'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Load PhotoSwipe library from CDN'),
      '#default_value' => $config->get('enable_cdn'),
      '#description' => $this->t('Loads the photoswipe library via a content delivery network (CDN).<br><strong>Note, that this may NOT comply with your regional data protection regulations.'),
    ];

    $form['photoswipe_always_load_non_admin'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Load PhotoSwipe on all non-admin pages'),
      '#default_value' => $config->get('photoswipe_always_load_non_admin'),
      '#description' => $this->t('Useful if you want to use photoswipe elsewhere by just adding the <code>.photoswipe</code> CSS class.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('photoswipe.settings')
      ->set('photoswipe_always_load_non_admin', $form_state->getValue('photoswipe_always_load_non_admin'))
      ->set('enable_cdn', $form_state->getValue('enable_cdn'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['photoswipe.settings'];
  }

}
